function [p,gam] = compute_p2w_PR(t,G,q,W)
% function [p,gam] = compute_p2w_PR(t,G,q,W)
%
% compute numerator of reduced system (positive real, uses YALMIP/SeDuMi)
%
% t --- discrete-time frequencies
% G --- frequency response of the original system
% q --- denominator of the reduced system in decreasing order
% weigthed version of compute_p1

% preprocessing
t = t(:);
G = G(:);
nt = size(t,1);
q = q(:)';
m = size(q,2)-1;    % order of reduced system
if nargin < 4
    W = ones(nt,1);
else
    W = W(:);
end

% define decision variables
Q = sdpvar(m);
p = sdpvar(m+1,1);

% matrices for objective function
qz = polyval(q,exp(j*t));
Z = exp(j*t*(m:-1:0));
obj = norm(W.*((Z*p)./qz-G),2);

% matrices for positive-real constraint
dd = 1e-8;
H = hankel(q);
T = toeplitz([q(1) ; zeros(m,1)],q);
P = H(end:-1:1,:)+T(end:-1:1,:); % the matrix actually used in LMI
Y = [Q P(1:(end-1),:)*p ; (P(1:(end-1),:)*p)' P(end,:)*p-dd]-[0 zeros(1,m) ; zeros(m,1) Q];
con = set(Y>0);

% setup optimization problem
solvesdp(con,obj);
Q = double(Q);
p = double(p)';
gam = norm(W.*((Z*p')./qz-G),2);