function p = compute_p2w_PR_Q(t,G,q,W,Q,gam)
% function p = compute_p2w_PR_Q(t,G,q,W,Q,gam)
%
% compute numerator of reduced system (positive real, ellipsoid algorithm)
%
% t --- discrete-time frequencies
% G --- frequency response of the original system
% q --- denominator of the reduced system in decreasing order
% weigthed version of compute_p1

% preprocessing
t = t(:);
G = G(:);
Q = Q(:);
nt = size(t,1);
q = q(:)';
m = size(q,2)-1;    % order of reduced system
if nargin < 6
    [p0,gam] = compute_p2w_PR(t,G,q,W);
end

% define decision variables
QQ = sdpvar(m);
p = sdpvar(m+1,1);

% matrices for transfer function matching constraint
qz = polyval(q,exp(j*t));
Z = exp(j*t*(m:-1:0));
con = norm(W.*((Z*p)./qz-G),2)<(gam/0.9);

% matrices for Q matching
Q_k = 1:length(Q);
obj = norm((imag(Z(Q_k,:))-diag(Q)*real(Z(Q_k,:)))*p+imag(1./qz(Q_k))-Q./real(qz(Q_k)),2);

% matrices for positive-real constraint
dd = 1e-8;
H = hankel(q);
T = toeplitz([q(1) ; zeros(m,1)],q);
P = H(end:-1:1,:)+T(end:-1:1,:); % the matrix actually used in LMI
Y = [QQ P(1:(end-1),:)*p ; (P(1:(end-1),:)*p)' P(end,:)*p-dd]-[0 zeros(1,m) ; zeros(m,1) QQ];
con = con+set(Y>0);

% setup optimization problem
solvesdp(con,obj);
QQ = double(QQ);
p = double(p)';