function demo(case_id)
% function demo(case_id)
%
% case_id --- there are 10 cases. default = 9, which seems to be good.
% Do not test case 6; measurment is wrong
%
% Construct a 10th order positive real reduced model from measured inductor
% data from Josh Peters.
%
% Show the matching of the real part and imaginary part of the impedance of
% the device; quality factor not shown because of the poor matching (can
% uncomment the last part of the demo file to check out Q)

load demo_data;

% find center frequency for CT to DT conversion (Tustin transform)
if nargin < 1
    case_id = 9;
end
G = fr11(:,case_id);
f0 = find_center_frequency(f,G); % center frequency for Tustin transform
t = 2*atan(f/f0); % DT frequency

% generate reduced model
m = 10; % order of ROM
r = 0.9;
W = 1./abs(G);
disp('generating reduced model ...');
sys = run_ellip_rpn_PR(G,t,m,r,W); % generate ROM
G1 = squeeze(freqresp(sys,t)); % frequency response
figure(1); plot(f,real(G),'.',f,real(G1));
xlabel('f (Hz)');
ylabel('real part');
legend('measurement','ROM');
figure(2); plot(f,imag(G),'.',f,imag(G1));
xlabel('f (Hz)');
ylabel('imaginary part');
legend('measurement','ROM');

% Quality factor result is bad -- do not show
% figure(3); plot(f,imag(G)./real(G),'.',f,imag(G1)./real(G1));
% xlabel('f (Hz)');
% ylabel('Q');
% legend('measurement','ROM');