function [L,ds] = fcheck_abc_PR(x)
% function [L,ds] = fcheck_abc_PR(x)
%
% feasibility check of x (a(t) > 0 and b(t) > 0)
% return cut L(x-x0) > ds (ds >=0) for all x in X
% ds = -inf means no cut is available

tol = 1e-8;
n = length(x);
m = floor(length(x)/3); % order of the fit
x = x(:)';  % make sure x is a row vector
ti = unique(angle(roots([(m:-1:1).*x(m:-1:1) 0 -(1:m).*x(1:m)]))); % stationary point frequencies
ti = ti(ti>=0);
[d,ind] = min(cos(ti(:)*(0:m))*[1;x(1:m)']);
if d <= tol % x is not feasible (a(t) <= 0 for some t)
    t = ti(ind);
    L = [cos((1:m)*t) zeros(1,n-m)];
    ds = -cos((0:m)*t)*[1 ; x(1:m)']+tol;
    return;
else % check if b(t) > 0 for all t
    ti = unique(angle(roots([(m:-1:1).*x((2*m+1):-1:(m+2)) 0 -(1:m).*x((m+2):(2*m+1))])));
    ti = ti(ti>=0);
    [d,ind] = min(cos(ti(:)*(0:m))*x((m+1):(2*m+1))');
    if isempty(ind)
        d = x(m+1);
    end
    if d > tol % x is feasible (a(t) > 0 and b(t) > 0 for all t
        L = zeros(1,n);
        ds = -inf;
    else
        if isempty(ind)
            t = 0;
        else
            t = ti(ind);
        end
        L = [zeros(1,m) cos((0:m)*t) zeros(1,m)];
        ds = -cos((0:m)*t)*x((m+1):(2*m+1))'+tol;
    end
end